@@ -30,6 +30,7 @@
 #include "vodafone_sender.h"
 #include "meteor_sender.h"
 #include "three_sender.h"
+#include "websmsru_sender.h"
 #include "blueface_sender.h"
 #include "web_proxy_sender.h"
 #include "betamax_sender.h"
@@ -70,7 +71,10 @@ void prepare_to_send(AppData *appdata, HTTP_Proxy *proxy)
 		 * Saving messages is still experimental so only available in debug mode
 		 */
 		if(appdata->settings.savemsg)
+		{
+			g_debug("attempting to save msg\n");
 			save_message(to, msg);
+		}
 
 		banner = hildon_banner_show_information(GTK_WIDGET(appdata->messageWindow), NULL,
 						"Message Sent");
@@ -103,7 +107,7 @@ void prepare_to_send(AppData *appdata, HTTP_Proxy *proxy)
 gint send_msg(AppSettings *settings, char* to, char* msg, HTTP_Proxy *proxy)
 {
 
-	if(settings->use_proxy_script && (settings->provider != BLUEFACE && settings->provider != OTHER_BETAMAX))
+	if(settings->use_proxy_script && (settings->provider != BLUEFACE && settings->provider != OTHER_BETAMAX && settings->provider != WEBSMSRU))
 	{
 		return web_proxy_send_message(settings, to, msg, proxy);
 	}
@@ -233,6 +237,10 @@ gint send_msg(AppSettings *settings, char* to, char* msg, HTTP_Proxy *proxy)
 	{
 		return blueface_send_message(settings, to, msg, proxy);
 	}
+	else if(settings->provider == WEBSMSRU)
+	{
+		return websmsru_send_message(settings, to, msg, proxy);
+	}
 	else
 	{
 		/*
@@ -276,7 +284,7 @@ void http_send_curl(const char* url, http_sender* sender, http_method method,
 		curl_easy_setopt(handle, CURLOPT_URL, url);
 		curl_easy_setopt(handle, CURLOPT_HEADER, 0);
 		curl_easy_setopt(handle, CURLOPT_COOKIEFILE, cookiefile);
-		/*curl_easy_setopt(handle, CURLOPT_VERBOSE, 1);*/
+		curl_easy_setopt(handle, CURLOPT_VERBOSE, 1);
 		curl_easy_setopt(handle, CURLOPT_COOKIEJAR, cookiejar);
 		curl_easy_setopt(handle, CURLOPT_TIMEOUT, 15);
 
