@@ -317,6 +317,7 @@ void settingsButton_clicked(GtkButton* button, AppData *appdata)
 		set_provider(appdata->gconf_client, appdata->settings.provider);
 		set_proxy(appdata->gconf_client, appdata->settings.use_proxy_script);
 		set_proxy_url(appdata->gconf_client, appdata->settings.proxy_url);
+		set_savemsg(appdata->gconf_client, appdata->settings.savemsg);
 	}
 	else
 	{
@@ -348,7 +349,7 @@ on_page_switch (GtkNotebook *notebook,
                 guint num,
                 GtkDialog *wizard)
 {
-	if(num != 4)
+	if(num != 5)
 		gtk_dialog_set_response_sensitive (GTK_DIALOG (wizard),
 		                                       HILDON_WIZARD_DIALOG_FINISH,
 		                                       FALSE);
@@ -420,6 +421,7 @@ some_page_func (GtkNotebook *nb,
 			GtkRadioButton *smsdiscount_but = GTK_RADIO_BUTTON(g_list_nth_data(pan, SMSDISCOUNT));
 			GtkRadioButton *lowratevoip_but = GTK_RADIO_BUTTON(g_list_nth_data(pan, LOWRATEVOIP));
 			GtkRadioButton *otherbetamax_but = GTK_RADIO_BUTTON(g_list_nth_data(pan, OTHER_BETAMAX));
+			GtkRadioButton *websmsru_but = GTK_RADIO_BUTTON(g_list_nth_data(pan, WEBSMSRU));
 
 			if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(o2_but)))
 				appsettings->provider = O2;
@@ -439,6 +441,8 @@ some_page_func (GtkNotebook *nb,
 				appsettings->provider = LOWRATEVOIP;
 			if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(otherbetamax_but)))
 				appsettings->provider = OTHER_BETAMAX;
+			if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(websmsru_but)))
+				appsettings->provider = WEBSMSRU;
 
 			return TRUE;
 		}
@@ -480,6 +484,20 @@ some_page_func (GtkNotebook *nb,
 			}
 
 		}
+		case 4:
+		{
+			GtkRadioButton *yes_save_but = GTK_RADIO_BUTTON(g_list_nth_data(children, 1));
+			GtkRadioButton *no_save_but = GTK_RADIO_BUTTON(g_list_nth_data(children, 2));
+			if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(yes_save_but)))
+			{
+				appsettings->savemsg = TRUE;
+			}
+			if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(no_save_but)))
+			{
+				appsettings->savemsg = FALSE;
+			}
+				return TRUE;
+		}
 		default:
 			return TRUE;
 	}
@@ -540,33 +558,34 @@ void sendButton_clicked (GtkButton* button, AppData *appdata)
 			appdata->settings.orientation_enabled = TRUE;
 		}
 	}
-	else if(strcmp(to, DEBUG_ENABLE) == 0)
+	else if(strcmp(to, EXTRA_LOGGING_ENABLE) == 0)
 	{
-
-		if(appdata->settings.savemsg)
+		if(appdata->settings.extra_logging)
 		{
-			g_debug("savemsg enabled");
-			appdata->settings.savemsg = FALSE;
+			banner = hildon_banner_show_information(GTK_WIDGET(appdata->messageWindow), NULL,
+							"Extra Logging disabled.");
+			g_debug("extra_logging disabled");
+			appdata->settings.extra_logging = FALSE;
 		}
 		else
 		{
-			g_debug("savemsg disabled");
-			appdata->settings.savemsg = TRUE;
+			banner = hildon_banner_show_information(GTK_WIDGET(appdata->messageWindow), NULL,
+										"Extra Logging Enabled.");
+			g_debug("extra_logging enabled");
+			appdata->settings.extra_logging = TRUE;
 		}
 	}
-
 	else if(msgCharCount == 0)
 	{
 		banner = hildon_banner_show_information(GTK_WIDGET(appdata->messageWindow), NULL,
 				"Cannot send. Message is empty");
 	}
-	else if (msgCharCount > MAX_MSG_SIZE)
+	else if (msgCharCount > get_max_msg_size(&appdata->settings))
 	{
-		/*
-		 * TODO MAX size should come from the define in the message as well as the if
-		 */
+		gchar *message = g_strdup_printf("Message Cannot be greater than %d Characters", get_max_msg_size(&appdata->settings));
 		banner = hildon_banner_show_information(GTK_WIDGET(appdata->messageWindow), NULL,
-						"Cannot Send more than 160 characters");
+						message);
+		g_free(message);
 	}
 	else
 	{
@@ -599,11 +618,13 @@ static void msg_changed(GtkTextBuffer *textbuffer, AppData *appdata)
 	gchar* labelText = g_strdup_printf("%d Characters", msgCharCount);
 	gtk_label_set_text(GTK_LABEL(appdata->msgSizeLabel), labelText);
 
-	if(msgCharCount == MAX_MSG_SIZE + 1)
+	if(msgCharCount == get_max_msg_size(&appdata->settings) + 1)
 	{
 		GtkWidget *msgToBigBanner;
+		gchar *message = g_strdup_printf("Message Cannot be greater than %d Characters", get_max_msg_size(&appdata->settings));
 		msgToBigBanner = hildon_banner_show_information(GTK_WIDGET(appdata->messageWindow), NULL,
-						"Message Cannot be greater than 160 Characters");
+						message);
+		g_free(message);
 	}
 
 	g_free(labelText);
@@ -617,12 +638,13 @@ gint create_settings_wizard(AppData *appdata)
 {
 	GtkWidget *wizard, *notebook;
 	GtkWidget *user_label, *pass_label, *number_label, *prov_label, *proxy_label, *done_label, *proxy_url_label;
-	GtkWidget *proxy_info_label, *url_info_label;
+	GtkWidget *proxy_info_label, *url_info_label, *savemsg_label, *savemsg_info_label;
 	GtkWidget *user_entry, *pass_entry, *number_entry, *proxy_url_entry;
 	GtkWidget *voda_button, *o2_button, *met_button, *three_button, *blueface_button, *voipcheap_button, *smsdiscount_button;
-	GtkWidget *lowratevoip_button, *other_betamax_button;
+	GtkWidget *lowratevoip_button, *other_betamax_button, *websmsru_button;
 	GtkWidget *yes_proxy, *no_proxy;
-	GtkWidget *up_hbox, *prov_hbox, *proxy_hbox, *proxy_url_hbox;
+	GtkWidget *yes_savemsg, *no_savemsg;
+	GtkWidget *up_hbox, *prov_hbox, *proxy_hbox, *proxy_url_hbox, *savemsg_hbox;
 	GtkWidget *prov_panable;
 
 	notebook = gtk_notebook_new ();
@@ -632,6 +654,7 @@ gint create_settings_wizard(AppData *appdata)
 	prov_hbox = gtk_vbox_new(FALSE, 8);
 	proxy_hbox = gtk_vbox_new(FALSE, 8);
 	proxy_url_hbox = gtk_vbox_new(FALSE, 8);
+	savemsg_hbox = gtk_vbox_new(FALSE, 8);
 
 	char* voda = VODA_L;
 	char* o2 = O2_L;
@@ -642,6 +665,7 @@ gint create_settings_wizard(AppData *appdata)
 	char* smsdisc = SMSDISC_L;
 	char* lowrv = LOWRV_L;
 	char* otherbm = OTHER_BETA_L;
+	char* websmsru = WEBSMSRU_L;
 
 	user_label = gtk_label_new ("Username");
 	pass_label = gtk_label_new ("Password");
@@ -650,11 +674,14 @@ gint create_settings_wizard(AppData *appdata)
 	proxy_label = gtk_label_new ("Use Web Proxy");
 	proxy_url_label = gtk_label_new ("Web Proxy Address (http://...");
 	done_label = gtk_label_new(
-		"Your settings are now configured. Enjoy using webtexter");
+		"Your settings are now configured. \nEnjoy using webtexter");
 	proxy_info_label = gtk_label_new(
 		"Send through the cabbage style web scripts.\nNote: These scripts are mainly aimed at Irish users.\nNever used for Blueface or Other Betamax");
 	url_info_label = gtk_label_new(
 		"For a named provider:\nif web proxy selected enter script address\nif web proxy not selected enter anything\nFor Other Betamax providers:\nplease enter the URL of the sms page. \nThis is normally in the format \nhttps://www.provider.com/myaccount/sendsms.php");
+	savemsg_label = gtk_label_new("Save sent messages:");
+	savemsg_info_label = gtk_label_new(
+		"Allows you to save sent messages.\nAfter saving they appear in the \nconversations application");
 
 	user_entry = hildon_entry_new (HILDON_SIZE_AUTO);
 	pass_entry = hildon_entry_new (HILDON_SIZE_AUTO);
@@ -711,6 +738,11 @@ gint create_settings_wizard(AppData *appdata)
 	gtk_toggle_button_set_mode(GTK_TOGGLE_BUTTON(other_betamax_button), FALSE);
 	hildon_gtk_widget_set_theme_size(other_betamax_button, HILDON_SIZE_FINGER_HEIGHT);
 
+	websmsru_button = hildon_gtk_radio_button_new_from_widget(HILDON_SIZE_AUTO , GTK_RADIO_BUTTON(other_betamax_button));
+	gtk_button_set_label(GTK_BUTTON(websmsru_button), websmsru);
+	gtk_toggle_button_set_mode(GTK_TOGGLE_BUTTON(websmsru_button), FALSE);
+	hildon_gtk_widget_set_theme_size(websmsru_button, HILDON_SIZE_FINGER_HEIGHT);
+
 
 	yes_proxy = hildon_gtk_radio_button_new(HILDON_SIZE_AUTO , NULL);
 	gtk_button_set_label(GTK_BUTTON(yes_proxy), "Use Web Proxy");
@@ -721,6 +753,15 @@ gint create_settings_wizard(AppData *appdata)
 	gtk_toggle_button_set_mode(GTK_TOGGLE_BUTTON(no_proxy), FALSE);
 	hildon_gtk_widget_set_theme_size(no_proxy, HILDON_SIZE_FINGER_HEIGHT);
 
+	yes_savemsg = hildon_gtk_radio_button_new(HILDON_SIZE_AUTO , NULL);
+	gtk_button_set_label(GTK_BUTTON(yes_savemsg), "Save sent messages");
+	gtk_toggle_button_set_mode(GTK_TOGGLE_BUTTON(yes_savemsg), FALSE);
+	hildon_gtk_widget_set_theme_size(yes_savemsg, HILDON_SIZE_FINGER_HEIGHT);
+	no_savemsg = hildon_gtk_radio_button_new_from_widget(HILDON_SIZE_AUTO , GTK_RADIO_BUTTON(yes_savemsg));
+	gtk_button_set_label(GTK_BUTTON(no_savemsg), "Don't save sent messages");
+	gtk_toggle_button_set_mode(GTK_TOGGLE_BUTTON(no_savemsg), FALSE);
+	hildon_gtk_widget_set_theme_size(no_savemsg, HILDON_SIZE_FINGER_HEIGHT);
+
 	/*
 	 * Set Default or already set values
 	 */
@@ -787,6 +828,11 @@ gint create_settings_wizard(AppData *appdata)
 				gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(other_betamax_button), TRUE);
 				break;
 			}
+			case WEBSMSRU:
+			{
+				gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(websmsru_button), TRUE);
+				break;
+			}
 		}
 	}
 	else
@@ -802,6 +848,15 @@ gint create_settings_wizard(AppData *appdata)
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(no_proxy), TRUE);
 	}
 
+	if(appdata->settings.savemsg)
+	{
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(yes_savemsg), TRUE);
+	}
+	else
+	{
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(no_savemsg), TRUE);
+	}
+
 	gtk_box_pack_start (GTK_BOX (up_hbox), user_label, FALSE, FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (up_hbox), user_entry, FALSE, FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (up_hbox), pass_label, FALSE, FALSE, 0);
@@ -819,6 +874,7 @@ gint create_settings_wizard(AppData *appdata)
 	gtk_box_pack_start (GTK_BOX (prov_hbox), smsdiscount_button, FALSE, FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (prov_hbox), lowratevoip_button, FALSE, FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (prov_hbox), other_betamax_button, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (prov_hbox), websmsru_button, FALSE, FALSE, 0);
 
 	hildon_pannable_area_add_with_viewport (
 	    HILDON_PANNABLE_AREA (prov_panable), prov_hbox);
@@ -830,17 +886,25 @@ gint create_settings_wizard(AppData *appdata)
 	gtk_box_pack_start (GTK_BOX (proxy_hbox), proxy_info_label, FALSE, FALSE, 0);
 
 
+
 	gtk_box_pack_start (GTK_BOX (proxy_url_hbox), proxy_url_label, FALSE, FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (proxy_url_hbox), proxy_url_entry, FALSE, FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (proxy_url_hbox), url_info_label, FALSE, FALSE, 0);
 
+	gtk_box_pack_start (GTK_BOX (savemsg_hbox), savemsg_label, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (savemsg_hbox), yes_savemsg, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (savemsg_hbox), no_savemsg, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (savemsg_hbox), savemsg_info_label, FALSE, FALSE, 0);
+
 	/* Append pages */
 	gtk_notebook_append_page (GTK_NOTEBOOK (notebook), up_hbox, NULL);
 	gtk_notebook_append_page (GTK_NOTEBOOK (notebook), prov_panable, NULL);
 	gtk_notebook_append_page (GTK_NOTEBOOK (notebook), proxy_hbox, NULL);
 	gtk_notebook_append_page (GTK_NOTEBOOK (notebook), proxy_url_hbox, NULL);
+	gtk_notebook_append_page (GTK_NOTEBOOK (notebook), savemsg_hbox, NULL);
 	gtk_notebook_append_page (GTK_NOTEBOOK (notebook), done_label, NULL);
 
+
 	wizard = hildon_wizard_dialog_new(GTK_WINDOW(appdata->messageWindow), "Settings", GTK_NOTEBOOK(notebook));
 
 	/* Set a handler for "switch-page" signal */
@@ -985,6 +1049,7 @@ int main( int argc, char* argv[] )
 			set_provider(appdata.gconf_client, appdata.settings.provider);
 			set_proxy(appdata.gconf_client, appdata.settings.use_proxy_script);
 			set_proxy_url(appdata.gconf_client, appdata.settings.proxy_url);
+			set_savemsg(appdata.gconf_client, appdata.settings.savemsg);
 		}
 		else
 		{
