@@ -53,6 +53,7 @@ G_BEGIN_DECLS
 #define LOWRV_L "Lowratevoip"
 #define LOWRV_S "l"
 #define OTHER_BETA_L "Other Betamax"
+#define WEBSMSRU_L "WebSMS.ru"
 
 typedef enum {
   O2 = 1,
@@ -63,7 +64,8 @@ typedef enum {
   VOIPCHEAP = 6,
   SMSDISCOUNT = 7,
   LOWRATEVOIP = 8,
-  OTHER_BETAMAX = 9
+  OTHER_BETAMAX = 9,
+  WEBSMSRU = 10
 
 } Providers;
 
@@ -77,6 +79,7 @@ typedef struct
 	gboolean savemsg;
 	gboolean orientation_enabled;
 	gboolean emulator;
+	gboolean extra_logging;
 	gchar* proxy_url;
 
 } AppSettings;
@@ -89,6 +92,8 @@ gboolean set_password(GConfClient *client, const gchar* password);
 gboolean set_provider(GConfClient *client, gint provider);
 gboolean set_proxy(GConfClient *client, gboolean use_proxy);
 gboolean set_proxy_url(GConfClient *client, const gchar* proxy_url);
+gboolean set_savemsg(GConfClient *client, gboolean savemsg);
+gint get_max_msg_size(AppSettings *settings);
 
 G_END_DECLS
 
